# torchutils

Convenience classes for training and hyperparameter tuning. These are just thin wrappers on top of PyTorch and Ax.

## Compatibility
Built using Python 3.7.

## Installation

```
pip install avilabs-torchutils
```

For full working examples see the `torchutils/examples` directory.
